aboutsummaryrefslogtreecommitdiff
path: root/desktop/gdm/doinst.sh
diff options
context:
space:
mode:
Diffstat (limited to 'desktop/gdm/doinst.sh')
-rw-r--r--desktop/gdm/doinst.sh15
1 files changed, 14 insertions, 1 deletions
diff --git a/desktop/gdm/doinst.sh b/desktop/gdm/doinst.sh
index b49d6a4e6536c..f0d59236c1bae 100644
--- a/desktop/gdm/doinst.sh
+++ b/desktop/gdm/doinst.sh
@@ -1,5 +1,18 @@
-# Set the wayland-session script executable:
+config() {
+ NEW="$1"
+ OLD="$(dirname $NEW)/$(basename $NEW .new)"
+ if [ ! -r $OLD ]; then
+ mv $NEW $OLD
+ elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
+ rm $NEW
+ fi
+}
+
+config etc/gdm/custom.conf.new
+
+# Set the wayland-session script and gdm wrapper executable:
( cd etc/gdm ; chmod 0755 wayland-session )
+( cd usr/sbin ; chmod 0755 gdm )
if [ -e usr/share/glib-2.0/schemas ]; then
if [ -x /usr/bin/glib-compile-schemas ]; then